@@ -17,14 +17,13 @@
 
 package org.apache.xerces.parsers;
 
-import java.io.InputStream;
-import java.io.IOException;
+import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
-
-import java.util.Properties;
-import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.util.Properties;
 
 /**
  * This class is duplicated for each JAXP subpackage so keep it in sync.
@@ -38,7 +37,7 @@ import java.io.InputStreamReader;
  * when bundled as part of the JDK.
  * <p>
  *
- * @version $Id: ObjectFactory.java 558589 2007-07-23 02:41:55Z mrglavas $
+ * @version $Id: ObjectFactory.java 1391587 2012-09-28 18:40:04Z mrglavas $
  */
 final class ObjectFactory {
 
@@ -50,7 +49,7 @@ final class ObjectFactory {
     private static final String DEFAULT_PROPERTIES_FILENAME = "xerces.properties";
 
     /** Set to true for debugging */
-    private static final boolean DEBUG = false;
+    private static final boolean DEBUG = isDebugEnabled();
     
     /**
      * Default columns per line.
@@ -132,7 +131,7 @@ final class ObjectFactory {
         // Use the system property first
         try {
             String systemProp = SecuritySupport.getSystemProperty(factoryId);
-            if (systemProp != null) {
+            if (systemProp != null && systemProp.length() > 0) {
                 if (DEBUG) debugPrintln("found system property, value=" + systemProp);
                 return newInstance(systemProp, cl, true);
             }
@@ -254,11 +253,22 @@ final class ObjectFactory {
     //
     // Private static methods
     //
+    
+    /** Returns true if debug has been enabled. */
+    private static boolean isDebugEnabled() {
+        try {
+            String val = SecuritySupport.getSystemProperty("xerces.debug");
+            // Allow simply setting the prop to turn on debug
+            return (val != null && (!"false".equals(val)));
+        } 
+        catch (SecurityException se) {}
+        return false;
+    } // isDebugEnabled()
 
     /** Prints a message to standard error if debugging is enabled. */
     private static void debugPrintln(String msg) {
         if (DEBUG) {
-            System.err.println("JAXP: " + msg);
+            System.err.println("XERCES: " + msg);
         }
     } // debugPrintln(String)
 
@@ -352,10 +362,10 @@ final class ObjectFactory {
         throws ClassNotFoundException, ConfigurationError
     {
         //throw security exception if the calling thread is not allowed to access the package
-        //restrict the access to package as speicified in java.security policy
+        //restrict the access to package as specified in java.security policy
         SecurityManager security = System.getSecurityManager();
         if (security != null) {
-            final int lastDot = className.lastIndexOf(".");
+            final int lastDot = className.lastIndexOf('.');
             String packageName = className;
             if (lastDot != -1) packageName = className.substring(0, lastDot);
             security.checkPackageAccess(packageName);
